@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.19';
+$VERSION = '0.20';
 
 #--------------------------------------------------------------------------
 
@@ -86,7 +86,7 @@ my %currencies; # only need to load once!
 my @defaults = ('source', 'target', 'format');
 
 my $web = WWW::Mechanize->new();
-$web->agent_alias( 'Linux Mozilla' );
+$web->agent_alias( 'Mac Safari' );
 
 #--------------------------------------------------------------------------
 
